@@ -1,4 +1,7 @@
 """Declares :class:`TemplateService`."""
+import functools
+import operator
+
 import django.template.loader
 
 
@@ -14,6 +17,10 @@ class TemplateService:
     def abspath(self, template_name):
         """Return a list holding the full paths to `template_name`."""
         template_names = []
+        if isinstance(template_name, (list, tuple)):
+            return functools.reduce(operator.add,
+                [self.abspath(x) for x in template_name], [])
+
         if self.prefix:
             template_names.append(self._prefix_template_name(template_name))
         template_names.append(template_name)
